// This file is autogenerated. Changes will be overwritten.
#include "EWIEGA46WW/moc_mpris.cpp"
#include "EWIEGA46WW/moc_mprisfactory.cpp"
#include "EWIEGA46WW/moc_player2object.cpp"
#include "EWIEGA46WW/moc_root2object.cpp"
