// This file is autogenerated. Changes will be overwritten.
#include "EWIEGA46WW/moc_effectladspafactory.cpp"
#include "EWIEGA46WW/moc_ladspabutton.cpp"
#include "EWIEGA46WW/moc_ladspahost.cpp"
#include "EWIEGA46WW/moc_ladspasettingsdialog.cpp"
#include "EWIEGA46WW/moc_ladspaslider.cpp"
